==> jersey-examples-2.26-wls1213.zip: wls1213/jersey/examples/cdi-webapp/src/test/java/org/glassfish/jersey/examples/cdi/resources/PerApplicationBeanTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.examples.cdi.resources;

import javax.ws.rs.client.Entity;
import javax.ws.rs.client.WebTarget;

import org.junit.Test;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.CoreMatchers.containsString;

/**
 * Test for the application scoped managed bean resource.
 *
 * @author Jakub Podlesak (jakub.podlesak at oracle.com)
 */
public class PerApplicationBeanTest extends CdiTest {

    @Test
    public void testApplicationScopedResource() {

        final WebTarget singleton = target().path("singleton");

        String s = singleton.request().get(String.class);
        assertThat(s, containsString(singleton.getUri().toString()));
        assertThat(s, containsString("GET"));

        final WebTarget counter = singleton.path("counter");

        // TODO: JERSEY-2744:
        // TODO: @Resource injection will not work on SE
        // TODO: add a custom extension to make this work with Grizzly
//        String c42 = counter.request().get(String.class);
//        assertThat(c42, containsString("42"));
//
//        String c43 = counter.request().get(String.class);
//        assertThat(c43, containsString("43"));

        counter.request().put(Entity.text("12"));

        String c12 = counter.request().get(String.class);
        assertThat(c12, containsString("12"));

        counter.request().put(Entity.text("42"));
    }
}

==> jersey-examples-2.45-wls1213.zip: wls1213/jersey/examples/cdi-webapp/src/test/java/org/glassfish/jersey/examples/cdi/resources/PerApplicationBeanTest.java <==
/*
 * Copyright (c) 2013, 2022 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package org.glassfish.jersey.examples.cdi.resources;

import javax.ws.rs.client.Entity;
import javax.ws.rs.client.WebTarget;

import org.junit.jupiter.api.Test;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.CoreMatchers.containsString;

/**
 * Test for the application scoped managed bean resource.
 *
 * @author Jakub Podlesak
 */
public class PerApplicationBeanTest extends CdiTest {

    @Test
    public void testApplicationScopedResource() {

        final WebTarget singleton = target().path("singleton");

        String s = singleton.request().get(String.class);
        assertThat(s, containsString(singleton.getUri().toString()));
        assertThat(s, containsString("GET"));

        final WebTarget counter = singleton.path("counter");

        // TODO: JERSEY-2744:
        // TODO: @Resource injection will not work on SE
        // TODO: add a custom extension to make this work with Grizzly
//        String c42 = counter.request().get(String.class);
//        assertThat(c42, containsString("42"));
//
//        String c43 = counter.request().get(String.class);
//        assertThat(c43, containsString("43"));

        counter.request().put(Entity.text("12"));

        String c12 = counter.request().get(String.class);
        assertThat(c12, containsString("12"));

        counter.request().put(Entity.text("42"));
    }
}
